package com.me.asteroids.systems;

import com.badlogic.gdx.math.Polygon;
import com.badlogic.gdx.math.Vector2;
import com.me.asteroids.components.AccelerationComponent;
import com.me.asteroids.components.ModelComponent;
import com.me.asteroids.components.PositionComponent;
import com.me.asteroids.components.VelocityComponent;
import com.me.common.ecs.Entity;
import com.me.common.ecs.EntitySystem;

public class MovementSystem extends EntitySystem {

    private Vector2 tmp = new Vector2();

    public MovementSystem() {
        super(PositionComponent.class, VelocityComponent.class);
    }

    @Override
    public void processEntity(Entity entity, float dt) {
        PositionComponent positionComponent = entity.getComponent(PositionComponent.class);
        VelocityComponent velocityComponent = entity.getComponent(VelocityComponent.class);

        Vector2 velocity = velocityComponent.velocity;
        float maxVelocity = velocityComponent.maxVelocity;
        Vector2 position = positionComponent.position;

        AccelerationComponent accelComponent = entity.getComponent(AccelerationComponent.class);
        if (accelComponent != null && !accelComponent.acceleration.isZero()) {
            velocity.add(tmp.set(accelComponent.acceleration).scl(dt));
        }

        if (!velocity.isZero()) {
            velocity.clamp(0, maxVelocity);
            position.add(tmp.set(velocity).scl(dt));
        }

        ModelComponent modelComponent = entity.getComponent(ModelComponent.class);
        if (modelComponent != null) {
            Polygon model = modelComponent.model;
            model.setPosition(position.x, position.y);
            model.setRotation(positionComponent.rotation - 90);
        }
    }

}
