package com.me.asteroids.systems;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Input;
import com.badlogic.gdx.math.Vector2;
import com.me.asteroids.Utils;
import com.me.asteroids.components.AccelerationComponent;
import com.me.asteroids.components.PlayerComponent;
import com.me.asteroids.components.PositionComponent;
import com.me.asteroids.components.VelocityComponent;
import com.me.common.ecs.Entity;
import com.me.common.ecs.EntitySystem;

public class PlayerInputSystem extends EntitySystem {

    public Vector2 tmp = new Vector2(0, 1);

    public PlayerInputSystem() {
        super(
                PositionComponent.class,
                VelocityComponent.class,
                AccelerationComponent.class,
                PlayerComponent.class
        );
    }

    @Override
    public void processEntity(Entity entity, float dt) {
        PositionComponent positionComponent = entity.getComponent(PositionComponent.class);
        VelocityComponent velocityComponent = entity.getComponent(VelocityComponent.class);
        AccelerationComponent accelComponent = entity.getComponent(AccelerationComponent.class);

        if (Gdx.input.isKeyPressed(Input.Keys.D)) {
            positionComponent.rotation = Utils.rotate(positionComponent.rotation, -300 * dt);
        }

        if (Gdx.input.isKeyPressed(Input.Keys.A)) {
            positionComponent.rotation = Utils.rotate(positionComponent.rotation, 300 * dt);
        }

        Vector2 acceleration = accelComponent.acceleration;
        Vector2 velocity = velocityComponent.velocity;

        if (Gdx.input.isKeyPressed(Input.Keys.W)) {
            acceleration.set(Utils.setUnitVectorAngle(tmp, positionComponent.rotation).scl(500));
        } else {
            if (!velocity.isZero(1f)) {
                acceleration.set(Utils.setUnitVectorAngleRad(tmp, velocity.angleRad()).scl(-100));
            } else {
                acceleration.set(0, 0);
            }
        }
    }

}
